# QCFractal
[![Continuous Integration](https://github.com/MolSSI/QCFractal/workflows/Continuous%20Integration/badge.svg)](https://github.com/MolSSI/QCFractal/actions?query=workflow%3A%22Continuous+Integration%22)
[![codecov](https://codecov.io/gh/MolSSI/QCFractal/branch/master/graph/badge.svg)](https://codecov.io/gh/MolSSI/QCFractal)
[![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/MolSSI/QCFractal.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/MolSSI/QCFractal/context:python)
[![Documentation Status](https://readthedocs.org/projects/qcfractal/badge/?version=latest)](https://qcfractal.readthedocs.io/en/latest/?badge=latest)
[![Chat on Slack](https://img.shields.io/badge/chat-on_slack-green.svg?longCache=true&style=flat&logo=slack)](https://join.slack.com/t/qcarchive/shared_invite/enQtNDIzNTQ2OTExODk0LTE3MWI0YzBjNzVhNzczNDM0ZTA5MmQ1ODcxYTc0YTA1ZDQ2MTk1NDhlMjhjMmQ0YWYwOGMzYzJkZTM2NDlmOGM)

A distributed compute and database platform for quantum chemistry. See the [documentation](https://qcfractal.readthedocs.io) for more information.

# License

BSD-3C. See the [License File](LICENSE) for more information.
